# Changelog

## 1.1.0 (2025-12-01)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/avm-codes/sandbox-sdk-python/compare/v1.0.0...v1.1.0)

### Features

* **api:** api update ([8da21c4](https://github.com/avm-codes/sandbox-sdk-python/commit/8da21c400c602db2fe38be70c8324693625d080a))


### Bug Fixes

* ensure streams are always closed ([85f7b3b](https://github.com/avm-codes/sandbox-sdk-python/commit/85f7b3bb30d7a65867ac231aa28dd931b92233df))


### Chores

* add Python 3.14 classifier and testing ([a0d25a0](https://github.com/avm-codes/sandbox-sdk-python/commit/a0d25a0c99592441305c2ab7d21ea288bd337226))
* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([409dcc8](https://github.com/avm-codes/sandbox-sdk-python/commit/409dcc828c8307133a1a8da2294c981f23b6b59e))

## 1.0.0 (2025-11-13)

Full Changelog: [v0.0.1...v1.0.0](https://github.com/avm-codes/sandbox-sdk-python/compare/v0.0.1...v1.0.0)

### Chores

* configure new SDK language ([ae1bc06](https://github.com/avm-codes/sandbox-sdk-python/commit/ae1bc06d0c6274651a194a434ae0240467dfc22a))
* update SDK settings ([50385a7](https://github.com/avm-codes/sandbox-sdk-python/commit/50385a71a857af075188c76f4363ef8c880f3b65))
* update SDK settings ([cde1082](https://github.com/avm-codes/sandbox-sdk-python/commit/cde108200bbc0424a6e7acc1d1217f3f5d613a7a))
